[Mlir-commits] [mlir] a23d055 - [mlir] NFC: fix trivial typo under test and tools

Kazuaki Ishizaki llvmlistbot at llvm.org
Wed Aug 26 23:37:55 PDT 2020


Author: Kazuaki Ishizaki
Date: 2020-08-27T15:37:42+09:00
New Revision: a23d055912c447dcfa54049b5a06b663560e3827

URL: https://github.com/llvm/llvm-project/commit/a23d055912c447dcfa54049b5a06b663560e3827
DIFF: https://github.com/llvm/llvm-project/commit/a23d055912c447dcfa54049b5a06b663560e3827.diff

LOG: [mlir] NFC: fix trivial typo under test and tools

Reviewed By: rriddle

Differential Revision: https://reviews.llvm.org/D86648

Added: 
    

Modified: 
    mlir/integration_test/lit.cfg.py
    mlir/test/Dialect/Affine/loop-tiling.mlir
    mlir/test/Dialect/Affine/simplify-affine-structures.mlir
    mlir/test/Dialect/LLVMIR/invalid.mlir
    mlir/test/Dialect/Linalg/tensors-to-buffers.mlir
    mlir/test/IR/pretty-attributes.mlir
    mlir/test/Target/llvmir-types.mlir
    mlir/test/Target/llvmir.mlir
    mlir/test/Transforms/buffer-placement.mlir
    mlir/test/Transforms/test-legalizer.mlir
    mlir/test/Transforms/test-merge-blocks.mlir
    mlir/test/lib/Dialect/Test/TestOps.td
    mlir/test/lib/Dialect/Test/TestPatterns.cpp
    mlir/test/lib/IR/TestTypes.cpp
    mlir/test/lib/Transforms/TestConvertCallOp.cpp
    mlir/test/lib/Transforms/TestMemRefBoundCheck.cpp
    mlir/test/mlir-reduce/dce-test.mlir
    mlir/tools/mlir-reduce/Passes/OpReducer.cpp
    mlir/tools/mlir-tblgen/OpDefinitionsGen.cpp
    mlir/tools/mlir-tblgen/OpInterfacesGen.cpp
    mlir/tools/mlir-vulkan-runner/CMakeLists.txt
    mlir/unittests/Analysis/AffineStructuresTest.cpp
    mlir/unittests/TableGen/OpBuildGen.cpp

Removed: 
    


################################################################################
diff  --git a/mlir/integration_test/lit.cfg.py b/mlir/integration_test/lit.cfg.py
index 7651af85c8aa..106bfcd3c59b 100644
--- a/mlir/integration_test/lit.cfg.py
+++ b/mlir/integration_test/lit.cfg.py
@@ -36,7 +36,7 @@
 
 llvm_config.use_default_substitutions()
 
-# excludes: A list of directories to exclude from the integraiton testsuite.
+# excludes: A list of directories to exclude from the integration testsuite.
 config.excludes = ['CMakeLists.txt', 'README.txt', 'LICENSE.txt']
 
 # Tweak the PATH to include the tools dir.

diff  --git a/mlir/test/Dialect/Affine/loop-tiling.mlir b/mlir/test/Dialect/Affine/loop-tiling.mlir
index 0e83b3fa16f6..0bd360b4644e 100644
--- a/mlir/test/Dialect/Affine/loop-tiling.mlir
+++ b/mlir/test/Dialect/Affine/loop-tiling.mlir
@@ -208,7 +208,7 @@ func @trip_count_one(%arg0: memref<196608x1xf32>, %arg1: memref<196608x1xf32>)
   // CHECK: affine.load %{{.*}}[%{{.*}}, %{{.*}}] : memref<196608x1xf32>
   return %arg1 : memref<196608x1xf32>
 }
-// To make sure SEPRATE-DAGs further below do not match with something above.
+// To make sure SEPARATE-DAGs further below do not match with something above.
 // SEPARATE: return
 
 // -----

diff  --git a/mlir/test/Dialect/Affine/simplify-affine-structures.mlir b/mlir/test/Dialect/Affine/simplify-affine-structures.mlir
index 11fb0b128d63..e3680632b85b 100644
--- a/mlir/test/Dialect/Affine/simplify-affine-structures.mlir
+++ b/mlir/test/Dialect/Affine/simplify-affine-structures.mlir
@@ -288,7 +288,7 @@ func @simplify_zero_dim_map(%in : memref<f32>) -> f32 {
 // CHECK-DAG: #[[$map0:.*]] = affine_map<()[s0, s1] -> (-(s1 floordiv s0) + 2)>
 // CHECK-DAG: #[[$map1:.*]] = affine_map<()[s0, s1] -> (-(s1 floordiv s0) + 42)>
 
-// Tests the simplification of a semi-affine expression with a modulo operartion on a floordiv and multiplication.
+// Tests the simplification of a semi-affine expression with a modulo operation on a floordiv and multiplication.
 // CHECK-LABEL: func @semiaffine_mod
 func @semiaffine_mod(%arg0: index, %arg1: index) -> index {
   %a = affine.apply affine_map<(d0)[s0] ->((-((d0 floordiv s0) * s0) + s0 * s0) mod s0)> (%arg0)[%arg1]

diff  --git a/mlir/test/Dialect/LLVMIR/invalid.mlir b/mlir/test/Dialect/LLVMIR/invalid.mlir
index 4260d8a053e1..52b0334dd96b 100644
--- a/mlir/test/Dialect/LLVMIR/invalid.mlir
+++ b/mlir/test/Dialect/LLVMIR/invalid.mlir
@@ -48,7 +48,7 @@ func @alloca_missing_input_type() {
 
 // -----
 
-func @alloca_mising_result_type() {
+func @alloca_missing_result_type() {
   // expected-error at +1 {{expected trailing function type with one argument and one result}}
   llvm.alloca %size x !llvm.i32 : (!llvm.i64) -> ()
 }

diff  --git a/mlir/test/Dialect/Linalg/tensors-to-buffers.mlir b/mlir/test/Dialect/Linalg/tensors-to-buffers.mlir
index a744d14af74a..ed4f32b28ac3 100644
--- a/mlir/test/Dialect/Linalg/tensors-to-buffers.mlir
+++ b/mlir/test/Dialect/Linalg/tensors-to-buffers.mlir
@@ -2,8 +2,8 @@
 
 #map0 = affine_map<(d0) -> (d0)>
 
-// CHECK-LABEL: func @muliple_results_generic_op
-func @muliple_results_generic_op(%arg0: tensor<4xf32>) -> (tensor<4xf32>, tensor<4xf32>) {
+// CHECK-LABEL: func @multiple_results_generic_op
+func @multiple_results_generic_op(%arg0: tensor<4xf32>) -> (tensor<4xf32>, tensor<4xf32>) {
     %0, %1 = linalg.generic {args_in = 1 : i64, args_out = 2 : i64, indexing_maps = [#map0, #map0, #map0], iterator_types = ["parallel"]} %arg0 {
     ^bb0(%gen_arg1: f32):
         %tmp1 = exp %gen_arg1 : f32

diff  --git a/mlir/test/IR/pretty-attributes.mlir b/mlir/test/IR/pretty-attributes.mlir
index bbcbe5b7b38c..e4e5b34f0a6d 100644
--- a/mlir/test/IR/pretty-attributes.mlir
+++ b/mlir/test/IR/pretty-attributes.mlir
@@ -15,4 +15,4 @@
 "test.sparse_attr"() {foo.sparse_attr = sparse<[[1, 2, 3]],  -2.0> : vector<1x1x1xf16>} : () -> ()
 
 // CHECK: opaque<"", "0xDEADBEEF"> : tensor<100xf32>
-"test.opaue_attr"() {foo.opaque_attr = opaque<"", "0xEBFE"> : tensor<100xf32> } : () -> ()
+"test.opaque_attr"() {foo.opaque_attr = opaque<"", "0xEBFE"> : tensor<100xf32> } : () -> ()

diff  --git a/mlir/test/Target/llvmir-types.mlir b/mlir/test/Target/llvmir-types.mlir
index 77f7800d8e53..d01bc2dbdf70 100644
--- a/mlir/test/Target/llvmir-types.mlir
+++ b/mlir/test/Target/llvmir-types.mlir
@@ -163,7 +163,7 @@ llvm.func @return_s_opaque() -> !llvm.struct<"opaque", opaque>
 // CHECK: declare %long
 llvm.func @return_s_long() -> !llvm.struct<"long", (i32, struct<(i32, i1)>, float, ptr<func<void ()>>)>
 // CHECK: declare %self-recursive
-llvm.func @return_s_self_recurisve() -> !llvm.struct<"self-recursive", (ptr<struct<"self-recursive">>)>
+llvm.func @return_s_self_recursive() -> !llvm.struct<"self-recursive", (ptr<struct<"self-recursive">>)>
 // CHECK: declare %unpacked
 llvm.func @return_s_unpacked() -> !llvm.struct<"unpacked", (i32)>
 // CHECK: declare %packed

diff  --git a/mlir/test/Target/llvmir.mlir b/mlir/test/Target/llvmir.mlir
index 24add42289ae..89f71477325d 100644
--- a/mlir/test/Target/llvmir.mlir
+++ b/mlir/test/Target/llvmir.mlir
@@ -1283,7 +1283,7 @@ llvm.func @volatile_store_and_load() {
 // -----
 
 // Check that nontemporal attribute is exported as metadata node.
-llvm.func @nontemoral_store_and_load() {
+llvm.func @nontemporal_store_and_load() {
   %val = llvm.mlir.constant(5 : i32) : !llvm.i32
   %size = llvm.mlir.constant(1 : i64) : !llvm.i64
   %0 = llvm.alloca %size x !llvm.i32 : (!llvm.i64) -> (!llvm.ptr<i32>)

diff  --git a/mlir/test/Transforms/buffer-placement.mlir b/mlir/test/Transforms/buffer-placement.mlir
index 2ac212c7d681..e1ed2c4309c3 100644
--- a/mlir/test/Transforms/buffer-placement.mlir
+++ b/mlir/test/Transforms/buffer-placement.mlir
@@ -589,7 +589,7 @@ func @moving_invalid_dealloc_op_complex(
 
 // -----
 
-// Test Case: Iserting missing DeallocOp in a single block.
+// Test Case: Inserting missing DeallocOp in a single block.
 
 #map0 = affine_map<(d0) -> (d0)>
 

diff  --git a/mlir/test/Transforms/test-legalizer.mlir b/mlir/test/Transforms/test-legalizer.mlir
index 5637fa853745..3a04ebfcea6d 100644
--- a/mlir/test/Transforms/test-legalizer.mlir
+++ b/mlir/test/Transforms/test-legalizer.mlir
@@ -238,7 +238,7 @@ func @undo_block_arg_replace() {
 
 // The op in this function is rewritten to itself (and thus remains illegal) by
 // a pattern that removes its second block after adding an operation into it.
-// Check that we can undo block removal succesfully.
+// Check that we can undo block removal successfully.
 // CHECK-LABEL: @undo_block_erase
 func @undo_block_erase() {
   // CHECK: test.undo_block_erase

diff  --git a/mlir/test/Transforms/test-merge-blocks.mlir b/mlir/test/Transforms/test-merge-blocks.mlir
index 65dd50569416..342c952b724e 100644
--- a/mlir/test/Transforms/test-merge-blocks.mlir
+++ b/mlir/test/Transforms/test-merge-blocks.mlir
@@ -20,7 +20,7 @@ func @merge_blocks(%arg0: i32, %arg1 : i32) -> () {
 // The op in this function is rewritten to itself (and thus remains
 // illegal) by a pattern that merges the second block with the first
 // after adding an operation into it.  Check that we can undo block
-// removal succesfully.
+// removal successfully.
 // CHECK-LABEL: @undo_blocks_merge
 func @undo_blocks_merge(%arg0: i32) {
   "test.undo_blocks_merge"() ({

diff  --git a/mlir/test/lib/Dialect/Test/TestOps.td b/mlir/test/lib/Dialect/Test/TestOps.td
index 9a94311776da..c938081b1642 100644
--- a/mlir/test/lib/Dialect/Test/TestOps.td
+++ b/mlir/test/lib/Dialect/Test/TestOps.td
@@ -1528,7 +1528,7 @@ def TableGenBuildOp3 : TEST_Op<"tblgen_build_3", [SameVariadicResultSize]> {
 }
 
 // Single variadic arg, non variadic results, with SameOperandsAndResultType.
-// Tests suppression of ambiguious build methods for operations with
+// Tests suppression of ambiguous build methods for operations with
 // SameOperandsAndResultType trait.
 def TableGenBuildOp4 : TEST_Op<"tblgen_build_4", [SameOperandsAndResultType]> {
   let arguments = (ins Variadic<AnyType>:$inputs);
@@ -1536,7 +1536,7 @@ def TableGenBuildOp4 : TEST_Op<"tblgen_build_4", [SameOperandsAndResultType]> {
 }
 
 // Single variadic arg with SameOperandsAndResultType and InferTypeOpInterface.
-// Tests suppression of ambiguious build methods for operations with
+// Tests suppression of ambiguous build methods for operations with
 // SameOperandsAndResultType and InferTypeOpInterface.
 def TableGenBuildOp5 : TEST_Op<"tblgen_build_5",
       [SameOperandsAndResultType, InferTypeOpInterface]> {

diff  --git a/mlir/test/lib/Dialect/Test/TestPatterns.cpp b/mlir/test/lib/Dialect/Test/TestPatterns.cpp
index cee87984cd88..5dd9adb684ce 100644
--- a/mlir/test/lib/Dialect/Test/TestPatterns.cpp
+++ b/mlir/test/lib/Dialect/Test/TestPatterns.cpp
@@ -63,7 +63,7 @@ struct FoldingPattern : public RewritePattern {
     // upon construction. The operation being created through the folder has an
     // in-place folder, and it should be still present in the output.
     // Furthermore, the folder should not crash when attempting to recover the
-    // (unchanged) opeation result.
+    // (unchanged) operation result.
     OperationFolder folder(op->getContext());
     Value result = folder.create<TestOpInPlaceFold>(
         rewriter, op->getLoc(), rewriter.getIntegerType(32), op->getOperand(0),
@@ -254,7 +254,7 @@ struct TestCreateBlock : public RewritePattern {
   }
 };
 
-/// A simple pattern that creates a block containing an invalid operaiton in
+/// A simple pattern that creates a block containing an invalid operation in
 /// order to trigger the block creation undo mechanism.
 struct TestCreateIllegalBlock : public RewritePattern {
   TestCreateIllegalBlock(MLIRContext *ctx)

diff  --git a/mlir/test/lib/IR/TestTypes.cpp b/mlir/test/lib/IR/TestTypes.cpp
index 37e322c610c1..43b2c05c7572 100644
--- a/mlir/test/lib/IR/TestTypes.cpp
+++ b/mlir/test/lib/IR/TestTypes.cpp
@@ -20,7 +20,7 @@ struct TestRecursiveTypesPass
   void runOnFunction() override {
     FuncOp func = getFunction();
 
-    // Just make sure recurisve types are printed and parsed.
+    // Just make sure recursive types are printed and parsed.
     if (func.getName() == "roundtrip")
       return;
 

diff  --git a/mlir/test/lib/Transforms/TestConvertCallOp.cpp b/mlir/test/lib/Transforms/TestConvertCallOp.cpp
index 980c54258ab8..67c45f1c28b7 100644
--- a/mlir/test/lib/Transforms/TestConvertCallOp.cpp
+++ b/mlir/test/lib/Transforms/TestConvertCallOp.cpp
@@ -1,4 +1,4 @@
-//===- TestConvertCallOp.cpp - Test LLVM Convesion of Standard CallOp -----===//
+//===- TestConvertCallOp.cpp - Test LLVM Conversion of Standard CallOp ----===//
 //
 // Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 // See https://llvm.org/LICENSE.txt for license information.

diff  --git a/mlir/test/lib/Transforms/TestMemRefBoundCheck.cpp b/mlir/test/lib/Transforms/TestMemRefBoundCheck.cpp
index 4ae9e505cab3..b7e84f695c71 100644
--- a/mlir/test/lib/Transforms/TestMemRefBoundCheck.cpp
+++ b/mlir/test/lib/Transforms/TestMemRefBoundCheck.cpp
@@ -27,7 +27,7 @@ using namespace mlir;
 
 namespace {
 
-/// Checks for out of bound memef access subscripts..
+/// Checks for out of bound memref access subscripts..
 struct TestMemRefBoundCheck
     : public PassWrapper<TestMemRefBoundCheck, FunctionPass> {
   void runOnFunction() override;

diff  --git a/mlir/test/mlir-reduce/dce-test.mlir b/mlir/test/mlir-reduce/dce-test.mlir
index e368343e056a..35f245200d35 100644
--- a/mlir/test/mlir-reduce/dce-test.mlir
+++ b/mlir/test/mlir-reduce/dce-test.mlir
@@ -1,7 +1,7 @@
 // UNSUPPORTED: -windows-
 // RUN: mlir-reduce %s -test %S/failure-test.sh -pass-test DCE | FileCheck %s
 // This input should be reduced by the pass pipeline so that only
-// the @simple1 function remains as the other fucntions should be
+// the @simple1 function remains as the other functions should be
 // removed by the dead code elimination pass.
 // CHECK-LABEL: func @simple1(%arg0: i1, %arg1: memref<2xf32>, %arg2: memref<2xf32>) {
 

diff  --git a/mlir/tools/mlir-reduce/Passes/OpReducer.cpp b/mlir/tools/mlir-reduce/Passes/OpReducer.cpp
index d94e80384cf7..0636e38ad886 100644
--- a/mlir/tools/mlir-reduce/Passes/OpReducer.cpp
+++ b/mlir/tools/mlir-reduce/Passes/OpReducer.cpp
@@ -24,7 +24,7 @@ StringRef OpReducerImpl::getName() {
   return StringRef("High Level Operation Reduction");
 }
 
-/// Return the initial transformSpace cointaing the transformable indices.
+/// Return the initial transformSpace containing the transformable indices.
 std::vector<bool> OpReducerImpl::initTransformSpace(ModuleOp module) {
   auto ops = getSpecificOps(module);
   int numOps = std::distance(ops.begin(), ops.end());

diff  --git a/mlir/tools/mlir-tblgen/OpInterfacesGen.cpp b/mlir/tools/mlir-tblgen/OpInterfacesGen.cpp
index 8b27bc6de7c5..54826f4618c4 100644
--- a/mlir/tools/mlir-tblgen/OpInterfacesGen.cpp
+++ b/mlir/tools/mlir-tblgen/OpInterfacesGen.cpp
@@ -115,7 +115,7 @@ struct AttrInterfaceGenerator : public InterfaceGenerator {
                             "(*static_cast<const ConcreteAttr *>(this))");
   }
 };
-/// A specialized generator for operaton interfaces.
+/// A specialized generator for operation interfaces.
 struct OpInterfaceGenerator : public InterfaceGenerator {
   OpInterfaceGenerator(const llvm::RecordKeeper &records, raw_ostream &os)
       : InterfaceGenerator(getAllOpInterfaceDefinitions(records), os) {

diff  --git a/mlir/tools/mlir-vulkan-runner/CMakeLists.txt b/mlir/tools/mlir-vulkan-runner/CMakeLists.txt
index b6febb61b000..c7a03259bb83 100644
--- a/mlir/tools/mlir-vulkan-runner/CMakeLists.txt
+++ b/mlir/tools/mlir-vulkan-runner/CMakeLists.txt
@@ -45,7 +45,7 @@ if (MLIR_VULKAN_RUNNER_ENABLED)
 
   # *IMPORTANT*: This library cannot depend on LLVM libraries. Otherwise,
   # it may cause LLVM version conflict when used together with other shared
-  # libraries depending on LLVM. Notably, Mesa, who implemnents Vulkan
+  # libraries depending on LLVM. Notably, Mesa, who implements Vulkan
   # drivers on Linux, depends on the system libLLVM.so.
   target_link_libraries(vulkan-runtime-wrappers
     PUBLIC

diff  --git a/mlir/unittests/Analysis/AffineStructuresTest.cpp b/mlir/unittests/Analysis/AffineStructuresTest.cpp
index eded4a889c7b..bf47f4c302a7 100644
--- a/mlir/unittests/Analysis/AffineStructuresTest.cpp
+++ b/mlir/unittests/Analysis/AffineStructuresTest.cpp
@@ -130,7 +130,7 @@ TEST(FlatAffineConstraintsTest, FindSampleTest) {
 
   // The next two sets are large sets that should take a long time to sample
   // with a naive branch and bound algorithm but can be sampled efficiently with
-  // the GBR algroithm.
+  // the GBR algorithm.
   //
   // This is a triangle with vertices at (1/3, 0), (2/3, 0) and (10000, 10000).
   checkSample(

diff  --git a/mlir/unittests/TableGen/OpBuildGen.cpp b/mlir/unittests/TableGen/OpBuildGen.cpp
index 46a37da6e944..0f089302358d 100644
--- a/mlir/unittests/TableGen/OpBuildGen.cpp
+++ b/mlir/unittests/TableGen/OpBuildGen.cpp
@@ -205,7 +205,7 @@ TEST_F(OpBuildGenTest,
   verifyOp(std::move(op), {i32Ty, f32Ty}, {cstI32}, attrs);
 }
 
-// The next 2 tests test supression of ambiguious build methods for ops that
+// The next 2 tests test supression of ambiguous build methods for ops that
 // have a single variadic input, and single non-variadic result, and which
 // support the SameOperandsAndResultType trait and and optionally the
 // InferOpTypeInterface interface. For such ops, the ODS framework generates


        


More information about the Mlir-commits mailing list
diff  --git a/mlir/tools/mlir-tblgen/OpDefinitionsGen.cpp b/mlir/tools/mlir-tblgen/OpDefinitionsGen.cpp
index 9f00b801710d..0b3ad38b035f 100644
--- a/mlir/tools/mlir-tblgen/OpDefinitionsGen.cpp
+++ b/mlir/tools/mlir-tblgen/OpDefinitionsGen.cpp
@@ -343,7 +343,7 @@ class OpEmitter {
 // - attrGet corresponds to the name of the function to call to get value of
 //   attribute (the generated function call returns an Attribute);
 // - operandGet corresponds to the name of the function with which to retrieve
-//   an operand (the generaed function call returns an OperandRange);
+//   an operand (the generated function call returns an OperandRange);
 // - reultGet corresponds to the name of the function to get an result (the
 //   generated function call returns a ValueRange);
 static void populateSubstitutions(const Operator &op, const char *attrGet,
@@ -996,14 +996,14 @@ void OpEmitter::genSeparateArgParamBuilder() {
     if (canInferType(op)) {
       // When inferType = true, the generated build method does not have
       // result types. If the op has a single variadic arg, then this build
       // method will be ambiguious with the collective inferred build method
       // generated in `genInferredTypeCollectiveParamBuilder`. If we are going
       // to generate that collective inferred method, suppress generating the
-      // ambiguious build method here.
-      bool buildMethodAmbiguious =
+      // ambiguous build method here.
+      bool buildMethodAmbiguous =
           op.hasSingleVariadicArg() &&
           shouldGenerateInferredTypeCollectiveParamBuilder();
-      if (!buildMethodAmbiguious)
+      if (!buildMethodAmbiguous)
         emit(attrType, TypeParamKind::None, /*inferType=*/true);
     }
     // The separate arg + collective param kind method will be:
@@ -1216,17 +1216,17 @@ void OpEmitter::genBuilder() {
     if (op.getTrait("OpTrait::SameOperandsAndResultType")) {
       // If the operation has a single variadic input, then the build method
       // generated by `genUseOperandAsResultTypeSeparateParamBuilder` will be
-      // ambiguious with the one generated by
+      // ambiguous with the one generated by
       // `genUseOperandAsResultTypeCollectiveParamBuilder` (they both will have
       // a single `ValueRange` argument for operands, and the collective one
       // will have a `ArrayRef<NamedAttribute>` argument initalized to empty).
       // Suppress such ambiguious build method.
       if (!op.hasSingleVariadicArg())
         genUseOperandAsResultTypeSeparateParamBuilder();
 
       // The build method generated by the inferred type collective param
       // builder and one generated here have the same arguments and hence
       // generating both will be ambiguious. Enable just one of them.
       if (!shouldGenerateInferredTypeCollectiveParamBuilder())
         genUseOperandAsResultTypeCollectiveParamBuilder();
     }
@@ -996,14 +996,14 @@ void OpEmitter::genSeparateArgParamBuilder() {
       // When inferType = true, the generated build method does not have
       // result types. If the op has a single variadic arg, then this build
-      // method will be ambiguious with the collective inferred build method
+      // method will be ambiguous with the collective inferred build method
       // generated in `genInferredTypeCollectiveParamBuilder`. If we are going
       // to generate that collective inferred method, suppress generating the
@@ -1216,17 +1216,17 @@ void OpEmitter::genBuilder() {
       // `genUseOperandAsResultTypeCollectiveParamBuilder` (they both will have
       // a single `ValueRange` argument for operands, and the collective one
-      // will have a `ArrayRef<NamedAttribute>` argument initalized to empty).
-      // Suppress such ambiguious build method.
+      // will have a `ArrayRef<NamedAttribute>` argument initialized to empty).
+      // Suppress such ambiguous build method.
       if (!op.hasSingleVariadicArg())
         genUseOperandAsResultTypeSeparateParamBuilder();
@@ -1216,17 +1216,17 @@ void OpEmitter::genBuilder() {
       // The build method generated by the inferred type collective param
       // builder and one generated here have the same arguments and hence
-      // generating both will be ambiguious. Enable just one of them.
+      // generating both will be ambiguous. Enable just one of them.
       if (!shouldGenerateInferredTypeCollectiveParamBuilder())
         genUseOperandAsResultTypeCollectiveParamBuilder();
